@@ -50,8 +50,8 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
                 "'--datarootdir=/usr/share' "
-                "'--docdir=/usr/share/doc/python-3.12.6_p4' "
-                "'--htmldir=/usr/share/doc/python-3.12.6_p4/html' "
+                "'--docdir=/usr/share/doc/python-3.12.7_p1' "
+                "'--htmldir=/usr/share/doc/python-3.12.7_p1/html' "
                 "'--libdir=/usr/lib64' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
@@ -64,7 +64,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
                 "'--without-assertions' '--disable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' "
-                "'--with-build-python=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python' "
+                "'--with-build-python=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python' "
                 "'build_alias=aarch64-unknown-linux-gnu' "
                 "'host_alias=riscv64-unknown-linux-gnu' "
                 "'PKG_CONFIG=riscv64-unknown-linux-gnu-pkg-config' "
@@ -74,9 +74,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6/coverage.info',
+ 'COVERAGE_INFO': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6/lcov-report',
+ 'COVERAGE_REPORT': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -123,9 +123,9 @@ build_time_vars = {'ABIFLAGS': '',
  'EXT_SUFFIX': '.cpython-312-riscv64-linux-gnu.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
- 'FREEZE_MODULE': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python '
+ 'FREEZE_MODULE': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python '
                   './Programs/_freeze_module.py',
- 'FREEZE_MODULE_BOOTSTRAP': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python '
+ 'FREEZE_MODULE_BOOTSTRAP': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python '
                             './Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': './Programs/_freeze_module.py',
  'FREEZE_MODULE_DEPS': './Programs/_freeze_module.py',
@@ -630,15 +630,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.12',
- 'INSTALL': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.m8mo_mkk/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.ymqoau7r/bin/ebuild-helpers/xattr/install '
             '-c',
- 'INSTALL_DATA': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.m8mo_mkk/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_DATA': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.ymqoau7r/bin/ebuild-helpers/xattr/install '
                  '-c -m 644',
- 'INSTALL_PROGRAM': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.m8mo_mkk/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_PROGRAM': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.ymqoau7r/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.m8mo_mkk/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.ymqoau7r/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.m8mo_mkk/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/riscv64-unknown-linux-gnu/tmp/portage/._portage_reinstall_.ymqoau7r/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -1039,15 +1039,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
- 'PYTHON_FOR_BUILD': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6 '
+ 'PYTHON_FOR_BUILD': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7 '
                      '_PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) '
                      'PYTHONPATH=$(shell test -f pybuilddir.txt && echo '
-                     '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6/`cat '
+                     '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/`cat '
                      'pybuilddir.txt`:)./Lib '
                      '_PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_riscv64-linux-gnu '
-                     '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python',
+                     '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python',
  'PYTHON_FOR_BUILD_DEPS': '',
- 'PYTHON_FOR_FREEZE': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python',
+ 'PYTHON_FOR_FREEZE': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
@@ -1230,21 +1230,21 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6 '
+ 'TESTPYTHON': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7 '
                '_PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) '
                'PYTHONPATH=$(shell test -f pybuilddir.txt && echo '
-               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6/`cat '
+               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/`cat '
                'pybuilddir.txt`:)./Lib '
                '_PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_riscv64-linux-gnu '
-               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python',
+               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6 '
+ 'TESTRUNNER': '_PYTHON_PROJECT_BASE=/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7 '
                '_PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) '
                'PYTHONPATH=$(shell test -f pybuilddir.txt && echo '
-               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6/`cat '
+               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7/`cat '
                'pybuilddir.txt`:)./Lib '
                '_PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_riscv64-linux-gnu '
-               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/python-3.12.6_p4-aarch64-unknown-linux-gnu/python '
+               '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/python-3.12.7_p1-aarch64-unknown-linux-gnu/python '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1274,8 +1274,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6',
- 'abs_srcdir': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.6_p4/work/Python-3.12.6',
+ 'abs_builddir': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7',
+ 'abs_srcdir': '/usr/riscv64-unknown-linux-gnu/tmp/portage/dev-lang/python-3.12.7_p1/work/Python-3.12.7',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
